OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Kontraste altua gaia",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste altuko gaia nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Gai iluna begiak leuntzeko argitasun orokorra eta distira murriztuz. Garapenean dagoen aukera da, beraz jakinarazi aurkitzen dituzun arazoak.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "Accessibility" : "Erabilerraztasuna",
    "Accessibility options for nextcloud" : "Erabilerraztasun aukerak nextcloudentzat",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Nextcloud-en erabilera errazteko hainbat aukera eskaintzen ditu.",
    "Web Content Accessibility Guidelines" : "Web Edukiaren Erabilerraztasun Jarraibideak",
    "our issue tracker" : "gure akats egunkaria",
    "our design team" : "gure diseinatzaile taldea",
    "Enable" : "Gaitu",
    "Dark theme (beta)" : "Gai beltza (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic dislexia eragindako ohiko irakurketa akats batzuk arintzeko diseinatuta dagoen tipografia/letra mota librea. Abelardo Gonzalezek sortu zuen tipografia hau eta  kode irekiko lizentzia baten bidez kaleratu zuen.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Hainbat irisgarritasun aukera eskaintzen ditu nextclouden erabilera errazteko",
    "Themes" : "Gaiak",
    "Fonts" : "Letra motak",
    "enabled" : "gaituta"
},
"nplurals=2; plural=(n != 1);");
